@@ -60,7 +60,8 @@ class EPNAdmin(admin.ModelAdmin):
 
 
 class IPNAdmin(admin.ModelAdmin):
-    list_display = ['code', 'name', 'price_group', 'shape', 'price_max']
+    list_display = ['code', 'code2', 'name', 'price_group', 'shape',
+                    'price_max']
     search_fields = ['code', 'name']
     list_filter = ['price_group']
 
